summaryrefslogtreecommitdiffstats
path: root/kommander/editor/formwindow.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kommander/editor/formwindow.cpp')
-rw-r--r--kommander/editor/formwindow.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kommander/editor/formwindow.cpp b/kommander/editor/formwindow.cpp
index d81bc0c3..e88dccd0 100644
--- a/kommander/editor/formwindow.cpp
+++ b/kommander/editor/formwindow.cpp
@@ -502,7 +502,7 @@ void FormWindow::handleMousePress(TQMouseEvent *e, TQWidget *w)
case POINTER_TOOL:
if (!isMainContainer(TQT_TQOBJECT(w)) && qstrcmp(w->name(), "central widget") != 0)
{ // press on a child widget
- // if the clicked widget is not in a tqlayout, raise it
+ // if the clicked widget is not in a layout, raise it
if (!w->parentWidget() || WidgetFactory::layoutType(w->parentWidget()) == WidgetFactory::NoLayout)
w->raise();
if ((e->state() & ControlButton))
@@ -520,7 +520,7 @@ void FormWindow::handleMousePress(TQMouseEvent *e, TQWidget *w)
clearSelection(false);
else
{ // ...widget selected
// only if widget has a tqlayout (it is a tqlayout meta widget or a laid out container!),
// unselect its childs
if (WidgetFactory::layoutType(w) != WidgetFactory::NoLayout)
{
@@ -861,16 +861,16 @@ void FormWindow::handleMouseRelease(TQMouseEvent * e, TQWidget * w)
if (wa == ((TQWidget *) it.key())->parentWidget())
goto make_move_command;
// break tqlayout if necessary
if (WidgetFactory::layoutType(wa) != WidgetFactory::NoLayout)
{
if (KMessageBox::questionYesNo(mainWindow(),
i18n("You tried to insert a widget into the "
- "tqlayout Container Widget '%1'.\n"
+ "layout Container Widget '%1'.\n"
"This is not possible. "
- "In order to insert the widget, the tqlayout of '%1'\n"
+ "In order to insert the widget, the layout of '%1'\n"
"must first be broken.\n"
- "Break the tqlayout or cancel the operation?").
+ "Break the layout or cancel the operation?").
arg(wa->name()).arg(wa->name()), i18n("Inserting Widget"),
i18n("&Break Layout"), KStdGuiItem::cancel()) == KMessageBox::No)
goto make_move_command; // cancel
@@ -955,11 +955,11 @@ void FormWindow::handleMouseRelease(TQMouseEvent * e, TQWidget * w)
{
if (KMessageBox::questionYesNo(mainWindow(),
i18n("You tried to insert a widget into the "
- "tqlayout Container Widget '%1'.\n"
+ "layout Container Widget '%1'.\n"
"This is not possible. "
- "In order to insert the widget, the tqlayout of '%1'\n"
+ "In order to insert the widget, the layout of '%1'\n"
"must first be broken.\n"
- "Break the tqlayout or cancel the operation?").
+ "Break the layout or cancel the operation?").
arg(insertParent->name()).
arg(insertParent->name()), i18n("Inserting Widget"),
i18n("&Break Layout"), KStdGuiItem::cancel()) == KMessageBox::Yes)
@@ -2502,7 +2502,7 @@ void FormWindow::setMainContainer(TQWidget *w)
delete mContainer;
mContainer = w;
insertedWidgets.insert(mContainer, mContainer);
- delete tqlayout();
+ delete layout();
TQHBoxLayout *l = new TQHBoxLayout(this);
l->addWidget(w);
if (resetPropertyWidget)
@@ -520,7 +520,7 @@ void FormWindow::handleMousePress(TQMouseEvent *e, TQWidget *w)
else
{ // ...widget selected
- // only if widget has a tqlayout (it is a tqlayout meta widget or a laid out container!),
+ // only if widget has a layout (it is a layout meta widget or a laid out container!),
// unselect its childs
if (WidgetFactory::layoutType(w) != WidgetFactory::NoLayout)
@@ -861,16 +861,16 @@ void FormWindow::handleMouseRelease(TQMouseEvent * e, TQWidget * w)
if (wa == ((TQWidget *) it.key())->parentWidget())
goto make_move_command;
- // break tqlayout if necessary
+ // break layout if necessary
if (WidgetFactory::layoutType(wa) != WidgetFactory::NoLayout)
{